pub struct EventStreamDecoder { /* private fields */ }Available on crate feature
aws only.Expand description
Incremental binary frame decoder.
Implementations
Sourceimpl EventStreamDecoder
impl EventStreamDecoder
Sourcepub fn next_frame(
&mut self,
) -> Result<Option<EventStreamFrame>, EventStreamParseError>
pub fn next_frame( &mut self, ) -> Result<Option<EventStreamFrame>, EventStreamParseError>
Try to parse the next complete frame. Returns Ok(None) when
the buffer does not yet contain a full frame, Ok(Some(_)) on
success, or Err(_) when the next frame’s prelude is
malformed (in which case the decoder’s state is corrupted —
callers should treat the stream as failed).
Sourcepub fn has_residual(&self) -> bool
pub fn has_residual(&self) -> bool
True when the internal buffer has bytes that have not yet completed a frame.